icsemantic.catalog.Extensions.install

Package platecom :: Package ontocatalog :: Package Extensions :: Module install |
[hide private]
[frames] | no frames]

# Module install

source code

Install the product.

Functions | [hide private]
StringIO |
install(self) External module to install the product. | source code
uninstall(self) Uninstall method. | source code

Function Details | [hide private]

### install(self) | source code
External module to install the product. Parameters: `self` (PloneSite) - The Plone site object Returns: StringIO Messages from the install process